==> haskell-syb-0.7.3-61.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 syb
version:              0.7.3
visibility:           public
id:                   syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
key:                  syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  24f4bfda09356018fa45b04d74524cc5
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7.3-69.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 syb
version:              0.7.3
visibility:           public
id:                   syb-0.7.3-4faDNy9a4q18QDGKds5is3
key:                  syb-0.7.3-4faDNy9a4q18QDGKds5is3
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  dd16bcdbea00a2cb823b03c01131cb5d
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/syb-0.7.3
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/syb-0.7.3
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/syb-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.3-4faDNy9a4q18QDGKds5is3
depends:              base-4.18.3.0
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
